#
# spec file for package kdebase4-runtime
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_package_requires %{name} = %{version}-%{release} kdelibs4-debuginfo
Name:           kdebase4-runtime
Version:        17.08.3
Release:        lp150.5.15
%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %global _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
Summary:        The KDE Runtime Components
License:        GPL-2.0+
Group:          System/GUI/KDE
Url:            http://www.kde.org/
Source0:        kde-runtime-%{version}.tar.xz
Source1:        kde4-essential.menu
Source2:        kde-settings.menu
Source3:        kde-settings.directory
Source4:        KDE-Sys-Log-Out.ogg
Patch1:         kdesu-remember-keep-password.diff
# PATCH-FIX-OPENSUSE
Patch2:         skip-nfs-kioslave.patch
Patch4:         ksuseinstall.diff
Patch5:         kdesu-symbol-lookup-workaround.diff
# PATCH-FIX-OPENSUSE kdesu-add-some-i18n-love.patch -- bnc#852256
Patch7:         kdesu-add-some-i18n-love.patch
# PATCH-FIX-OPENSUSE kde-runtime-glib2-include.patch -- mlin@suse.com
Patch8:         kde-runtime-glib2-include.patch
# PATCH-FIX-OPENSUSE
Patch9:         skip-qtwebkit-parts.patch
BuildRequires:  NetworkManager-devel
BuildRequires:  alsa-devel
BuildRequires:  automoc4
BuildRequires:  fdupes
BuildRequires:  libattica-devel >= 0.1.4
BuildRequires:  libcanberra-devel
BuildRequires:  libexiv2-devel
BuildRequires:  libgcrypt-devel >= 1.5.0
BuildRequires:  libgpgme-devel
BuildRequires:  libkactivities-devel >= 4.13.2
BuildRequires:  libkde4-devel
#!BuildIgnore:  kdebase4-runtime
BuildRequires:  libkdepimlibs4-devel
BuildRequires:  libksuseinstall-devel
# NTrack backend is used when ther is no NM or wicd, however it breaks ifup method, for details see https://bugs.kde.org/show_bug.cgi?id=294441#c23
#BuildRequires:  libntrack-qt4-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsmbclient-devel
BuildRequires:  libssh-devel >= 0.6.0
BuildRequires:  libtirpc-devel
BuildRequires:  lzma-devel
BuildRequires:  openexr-devel
BuildRequires:  openslp-devel
BuildRequires:  phonon-devel >= 4.3.80
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libwebp)
Requires:       dbus-1-x11
Requires:       kdelibs4
Requires:       libphonon4
# the oxygen icon theme is used as fallback by KDE4's icon loader and KDE4 applications may depend on it being installed (boo#1022821)
Requires:       oxygen-icon-theme
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         permissions
Requires(post): shared-mime-info
Requires(post): update-alternatives
Requires(postun): shared-mime-info
Requires(postun): update-alternatives
Recommends:     enscript
Recommends:     icoutils
Recommends:     ispell
Recommends:     kdialog
# KDE4 applications invoke khelpcenter, which is now provided by khelpcenter5
Recommends:     khelpcenter5 >= 17.04.1
Suggests:       cagibi
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{kde4_runtime_requires}

%description
This package contains all run-time dependencies of KDE applications.

%package -n plasma-theme-oxygen
Summary:        The Oxygen Plasma Theme
Group:          System/GUI/KDE
Provides:       kdebase4-runtime:%{_datadir}/kde4/apps/desktoptheme/oxygen/metadata.desktop

%description -n plasma-theme-oxygen
This package contains the Plasma theme Oxygen.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}

%description devel
This package contains development files and headers needed to
build software using %{name}

%prep
%setup -q -n kde-runtime-%{version}
cp %{SOURCE4} $RPM_BUILD_DIR/kde-runtime-%{version}/knotify/sounds/
%patch1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
# Superseded by khelpcenter5
rm -r $RPM_BUILD_DIR/kde-runtime-%{version}/khelpcenter
sed -i"" "/khelpcenter/d" $RPM_BUILD_DIR/kde-runtime-%{version}/doc/CMakeLists.txt
sed -i"" "/documentationnotfound/d" $RPM_BUILD_DIR/kde-runtime-%{version}/doc/CMakeLists.txt
sed -i"" "/glossary/d" $RPM_BUILD_DIR/kde-runtime-%{version}/doc/CMakeLists.txt

%build
  %cmake_kde4 -d build -- -DKDE4_ENABLE_FPIE=1
  %make_jobs

%install
  %kde4_makeinstall -C build
  rm -rf %{buildroot}%{_kde4_datadir}/wallpapers
  rm -rf %{buildroot}%{_kde4_iconsdir}/hicolor/index.theme
  rm -rf %{buildroot}%{_kde4_iconsdir}/oxygen
  rm -rf %{buildroot}%{_kde4_mandir}/man8/nepomukser*
  mkdir -p %{buildroot}%{_kde4_sysconfdir}/xdg/menus
  mv %{buildroot}%{_kde4_sysconfdir}/xdg/menus/kde-information.menu %{buildroot}%{_kde4_sysconfdir}/xdg/menus/kde4-information.menu
  mkdir -p %{buildroot}%{_kde4_sysconfdir}/xdg/menus/applications-merged
  install -m 644 %{SOURCE1} %{buildroot}%{_kde4_sysconfdir}/xdg/menus/applications-merged/kde4-essential.menu
  install -m 644 %{SOURCE2} %{buildroot}%{_kde4_sysconfdir}/xdg/menus/kde4-settings.menu
  install -m 644 %{SOURCE3} %{buildroot}%{_kde4_datadir}/desktop-directories/
  mkdir -p %{buildroot}%{_kde4_prefix}/bin
  # create a dummy target for %{_sysconfdir}/alternatives/kdesu
  install -d -m 755 %{buildroot}%{_sysconfdir}/alternatives/
  touch %{buildroot}%{_sysconfdir}/alternatives/kdesu
  chmod +x %{buildroot}%{_sysconfdir}/alternatives/kdesu
  ln -s -f %{_sysconfdir}/alternatives/kdesu %{buildroot}%{_kde4_bindir}/kdesu
  touch %{buildroot}%{_sysconfdir}/alternatives/kdesu.1%{?ext_man}
  mv %{buildroot}%{_kde4_mandir}/man1/kdesu.1 %{buildroot}%{_kde4_mandir}/man1/kdesu-4.1
  ln -s -f %{_sysconfdir}/alternatives/kdesu.1%{?ext_man} %{buildroot}%{_kde4_mandir}/man1/kdesu.1%{?ext_man}
  rm -rf %{buildroot}%{_kde4_includedir}/KDE
  # Conflicts with kuiserver5
  rm %{buildroot}/%{_datadir}/dbus-1/services/org.kde.kuiserver.service
  %suse_update_desktop_file -r knetattach    System Network
  %fdupes -s %{buildroot}
  %kde_post_install

%post
/sbin/ldconfig
%mime_database_post
%set_permissions %{_kde4_libexecdir}/kdesud
%{_sbindir}/update-alternatives \
    --install %{_kde4_bindir}/kdesu kdesu %{_kde4_libexecdir}/kdesu 20 \
    --slave %{_kde4_mandir}/man1/kdesu.1.gz kdesu.1%{?ext_man} %{_kde4_mandir}/man1/kdesu-4.1%{?ext_man}

%postun
/sbin/ldconfig
%mime_database_postun

if [ $1 -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove kdesu \
        %{_kde4_libexecdir}/kdesu
fi

%verifyscript
%verify_permissions -e %{_kde4_bindir}/kcheckpass
%verify_permissions -e %{_kde4_bindir}/kdesud
%verify_permissions -e %{_kde4_libexecdir}/kdesud

%files -n plasma-theme-oxygen
%defattr(-,root,root)
%doc COPYING
%{_kde4_appsdir}/desktoptheme/oxygen

%files devel
%defattr(-,root,root)
%{_kde4_includedir}/knotify_export*
%{_kde4_includedir}/knotifyconfig.h
%{_kde4_includedir}/knotifyplugin.h

%files
%defattr(-,root,root)
%doc COPYING COPYING.LIB

# --- knewstuff sources ---
%{_kde4_configdir}/emoticons.knsrc
%{_kde4_configdir}/icons.knsrc
%{_kde4_configdir}/khotnewstuff.knsrc
%{_kde4_configdir}/khotnewstuff_upload.knsrc

# --- menus ---
%config %{_kde4_sysconfdir}/xdg/menus/applications-merged
%config %{_kde4_sysconfdir}/xdg/menus/kde4-information.menu
%config %{_kde4_sysconfdir}/xdg/menus/kde4-settings.menu

# --- default configurations ---
%{_kde4_configkcfgdir}/jpegcreatorsettings.kcfg

# --- misc configuration ---
%{_kde4_configdir}/kshorturifilterrc

# --- man file manuals ---
%doc %{_kde4_mandir}/man1/kdesu*.1*
%ghost %{_sysconfdir}/alternatives/kdesu.1%{?ext_man}
%doc %{_kde4_mandir}/man1/plasmapkg.1.gz

# --- html manuals ---
%doc %lang(en) %{_kde4_htmldir}/en/kcontrol
%doc %lang(en) %{_kde4_htmldir}/en/kdebugdialog
%doc %lang(en) %{_kde4_htmldir}/en/kdesu
%doc %lang(en) %{_kde4_htmldir}/en/kioslave
%doc %lang(en) %{_kde4_htmldir}/en/knetattach
%doc %lang(en) %{_kde4_htmldir}/en/onlinehelp
%doc %lang(en) %{_kde4_htmldir}/en/fundamentals

# --- thumbnail generators ---
%{_kde4_modulesdir}/comicbookthumbnail.so
%{_kde4_modulesdir}/cursorthumbnail.so
%{_kde4_modulesdir}/djvuthumbnail.so
%{_kde4_modulesdir}/exrthumbnail.so
%{_kde4_modulesdir}/fixhosturifilter.so
%{_kde4_modulesdir}/imagethumbnail.so
%{_kde4_modulesdir}/jpegthumbnail.so
%{_kde4_modulesdir}/svgthumbnail.so
%{_kde4_modulesdir}/textthumbnail.so
%{_kde4_modulesdir}/windowsexethumbnail.so
%{_kde4_modulesdir}/windowsimagethumbnail.so

# --- kcm modules ---
%{_kde4_modulesdir}/kcm_attica.so
%{_kde4_modulesdir}/kcm_cgi.so
%{_kde4_modulesdir}/kcm_componentchooser.so
%{_kde4_modulesdir}/kcm_device_automounter.so
%{_kde4_modulesdir}/kcm_emoticons.so
%{_kde4_modulesdir}/kcm_filetypes.so
%{_kde4_modulesdir}/kcm_icons.so
%{_kde4_modulesdir}/kcm_kded.so
%{_kde4_modulesdir}/kcm_kdnssd.so
%{_kde4_modulesdir}/kcm_knotify.so
%{_kde4_modulesdir}/kcm_locale.so
%{_kde4_modulesdir}/kcm_phonon.so
%{_kde4_modulesdir}/kcmspellchecking.so
%{_kde4_modulesdir}/kcm_trash.so

# --- kded modules ---
%{_kde4_modulesdir}/kded_desktopnotifier.so
%{_kde4_modulesdir}/kded_device_automounter.so
%{_kde4_modulesdir}/kded_kpasswdserver.so
%{_kde4_modulesdir}/kded_ktimezoned.so
%{_kde4_modulesdir}/kded_networkstatus.so
%{_kde4_modulesdir}/kded_networkwatcher.so
%{_kde4_modulesdir}/kded_phononserver.so
%{_kde4_modulesdir}/kded_remotedirnotify.so
%{_kde4_modulesdir}/kded_solidautoeject.so
%{_kde4_modulesdir}/kded_soliduiserver.so

# --- kdeinit modules ---
%{_kde4_libdir}/libkdeinit4_kcmshell4.so
%{_kde4_libdir}/libkdeinit4_kglobalaccel.so
%{_kde4_libdir}/libkdeinit4_kuiserver.so
%{_kde4_libdir}/libkdeinit4_kwalletd.so

# --- kio slaves ---
%{_kde4_modulesdir}/kio_about.so
%{_kde4_modulesdir}/kio_applications.so
%{_kde4_modulesdir}/kio_archive.so
%{_kde4_modulesdir}/kio_bookmarks.so
%{_kde4_modulesdir}/kio_cgi.so
%{_kde4_modulesdir}/kio_desktop.so
%{_kde4_modulesdir}/kio_filter.so
%{_kde4_modulesdir}/kio_finger.so
%{_kde4_modulesdir}/kio_fish.so
%{_kde4_modulesdir}/kio_floppy.so
%{_kde4_modulesdir}/kio_info.so
%{_kde4_modulesdir}/kio_man.so
%{_kde4_modulesdir}/kio_network.so
%{_kde4_modulesdir}/kio_remote.so
%{_kde4_modulesdir}/kio_settings.so
%if 0%{?suse_version} >= 1310
%{_kde4_modulesdir}/kio_sftp.so
%endif
%{_kde4_modulesdir}/kio_smb.so
%{_kde4_modulesdir}/kio_thumbnail.so
%{_kde4_modulesdir}/kio_trash.so

# --- uri filters ---
%{_kde4_modulesdir}/kshorturifilter.so
%{_kde4_modulesdir}/kuriikwsfilter.so
%{_kde4_modulesdir}/kurisearchfilter.so
%{_kde4_modulesdir}/localdomainurifilter.so

# --- rename plugins ---
%{_kde4_modulesdir}/librenaudioplugin.so
%{_kde4_modulesdir}/librenimageplugin.so

# --- kparts ---
%{_kde4_modulesdir}/libkmanpart.so

# --- other ---
%{_kde4_libdir}/attica_kde.so
%{_kde4_libdir}/libknotifyplugin.so
%{_kde4_libdir}/libkwalletbackend.so
%{_kde4_libdir}/libmolletnetwork.so
%{_kde4_modulesdir}/plugins/imageformats/kimg_webp.so
%{_kde4_modulesdir}/plugins/phonon_platform
%{_kde4_modulesdir}/kio_recentdocuments.so
%{_kde4_modulesdir}/kded_recentdocumentsnotifier.so

# --- libexec ---
%verify(not mode) %attr(2755,root,nogroup) %{_kde4_libexecdir}/kdesud
%{_kde4_libexecdir}/kdeeject
%{_kde4_libexecdir}/kdesu
%{_kde4_libexecdir}/kdontchangethehostname
%{_kde4_libexecdir}/kioexec
%{_kde4_libexecdir}/knetattach

# --- apps directories ---
%dir %{_kde4_appsdir}/hardwarenotifications
%dir %{_kde4_appsdir}/kde
%dir %{_kde4_appsdir}/konqueror
%dir %{_kde4_appsdir}/konqueror/dirtree
%dir %{_kde4_appsdir}/konqueror/dirtree/remote

# --- apps ---
%exclude %{_kde4_appsdir}/desktoptheme/oxygen
%{_kde4_appsdir}/cmake
%{_kde4_appsdir}/desktoptheme
%{_kde4_appsdir}/hardwarenotifications/hardwarenotifications.notifyrc
%{_kde4_appsdir}/kcm_componentchooser
%{_kde4_appsdir}/kcmlocale
%{_kde4_appsdir}/kcm_phonon
%{_kde4_appsdir}/kconf_update/devicepreference.upd
%{_kde4_appsdir}/kconf_update/kuriikwsfilter.upd
%{_kde4_appsdir}/kde/kde.notifyrc
%{_kde4_appsdir}/kglobalaccel
%{_kde4_appsdir}/kio_bookmarks
%{_kde4_appsdir}/kio_desktop
%{_kde4_appsdir}/kio_docfilter
%{_kde4_appsdir}/kio_finger
%{_kde4_appsdir}/kio_info
%{_kde4_appsdir}/konqsidebartng
%{_kde4_appsdir}/konqueror/dirtree/remote/smb-network.desktop
%{_kde4_appsdir}/ksmserver
%{_kde4_appsdir}/kwalletd
%{_kde4_appsdir}/libphonon
%{_kde4_appsdir}/phonon
%{_kde4_appsdir}/remoteview

# --- protocols ---
%{_kde4_servicesdir}/about.protocol
%{_kde4_servicesdir}/applications.protocol
%{_kde4_servicesdir}/ar.protocol
%{_kde4_servicesdir}/bookmarks.protocol
%{_kde4_servicesdir}/bzip.protocol
%{_kde4_servicesdir}/bzip2.protocol
%{_kde4_servicesdir}/cgi.protocol
%{_kde4_servicesdir}/desktop.protocol
%{_kde4_servicesdir}/finger.protocol
%{_kde4_servicesdir}/fish.protocol
%{_kde4_servicesdir}/floppy.protocol
%{_kde4_servicesdir}/gzip.protocol
%{_kde4_servicesdir}/info.protocol
%{_kde4_servicesdir}/man.protocol
%{_kde4_servicesdir}/network.protocol
%{_kde4_servicesdir}/programs.protocol
%{_kde4_servicesdir}/recentdocuments.protocol
%{_kde4_servicesdir}/remote.protocol
%{_kde4_servicesdir}/settings.protocol
%{_kde4_servicesdir}/smb.protocol
%if 0%{?suse_version} >= 1310
%{_kde4_servicesdir}/sftp.protocol
%endif
%{_kde4_servicesdir}/tar.protocol
%{_kde4_servicesdir}/thumbnail.protocol
%{_kde4_servicesdir}/trash.protocol
%{_kde4_servicesdir}/zip.protocol
%{_kde4_servicesdir}/lzma.protocol
%{_kde4_servicesdir}/xz.protocol

# --- services ---
%{_kde4_servicesdir}/comicbookthumbnail.desktop
%{_kde4_servicesdir}/componentchooser.desktop
%{_kde4_servicesdir}/cursorthumbnail.desktop
%{_kde4_servicesdir}/desktopthumbnail.desktop
%{_kde4_servicesdir}/device_automounter_kcm.desktop
%{_kde4_servicesdir}/directorythumbnail.desktop
%{_kde4_servicesdir}/djvuthumbnail.desktop
%{_kde4_servicesdir}/emoticons.desktop
%{_kde4_servicesdir}/exrthumbnail.desktop
%{_kde4_servicesdir}/filetypes.desktop
%{_kde4_servicesdir}/fixhosturifilter.desktop
%{_kde4_servicesdir}/htmlthumbnail.desktop
%{_kde4_servicesdir}/icons.desktop
%{_kde4_servicesdir}/imagethumbnail.desktop
%{_kde4_servicesdir}/jpegthumbnail.desktop
%{_kde4_servicesdir}/kcm_attica.desktop
%{_kde4_servicesdir}/kcmcgi.desktop
%{_kde4_servicesdir}/kcmkded.desktop
%{_kde4_servicesdir}/kcm_kdnssd.desktop
%{_kde4_servicesdir}/kcmnotify.desktop
%{_kde4_servicesdir}/kcm_phonon.desktop
%{_kde4_servicesdir}/kcmtrash.desktop
%{_kde4_servicesdir}/kglobalaccel.desktop
%{_kde4_servicesdir}/kmanpart.desktop
%{_kde4_servicesdir}/knotify4.desktop
%{_kde4_servicesdir}/kshorturifilter.desktop
%{_kde4_servicesdir}/kuiserver.desktop
%{_kde4_servicesdir}/kuriikwsfilter.desktop
%{_kde4_servicesdir}/kurisearchfilter.desktop
%{_kde4_servicesdir}/kwalletd.desktop
%{_kde4_servicesdir}/language.desktop
%{_kde4_servicesdir}/localdomainurifilter.desktop
%{_kde4_servicesdir}/qimageioplugins/webp.desktop
%{_kde4_servicesdir}/renaudiodlg.desktop
%{_kde4_servicesdir}/renimagedlg.desktop
%{_kde4_servicesdir}/searchproviders
%{_kde4_servicesdir}/spellchecking.desktop
%{_kde4_servicesdir}/svgthumbnail.desktop
%{_kde4_servicesdir}/textthumbnail.desktop
%{_kde4_servicesdir}/windowsimagethumbnail.desktop
%{_kde4_servicesdir}/windowsexethumbnail.desktop

# --- kded services ---
%{_kde4_servicesdir}/kded/desktopnotifier.desktop
%{_kde4_servicesdir}/kded/device_automounter.desktop
%{_kde4_servicesdir}/kded/kpasswdserver.desktop
%{_kde4_servicesdir}/kded/ktimezoned.desktop
%{_kde4_servicesdir}/kded/networkstatus.desktop
%{_kde4_servicesdir}/kded/networkwatcher.desktop
%{_kde4_servicesdir}/kded/phononserver.desktop
%{_kde4_servicesdir}/kded/remotedirnotify.desktop
%{_kde4_servicesdir}/kded/solidautoeject.desktop
%{_kde4_servicesdir}/kded/soliduiserver.desktop
%{_kde4_servicesdir}/kded/recentdocumentsnotifier.desktop

# --- service types ---
%{_kde4_servicetypes}/knotifynotifymethod.desktop
%{_kde4_servicetypes}/phononbackend.desktop
%{_kde4_servicetypes}/searchprovider.desktop
%{_kde4_servicetypes}/thumbcreator.desktop

# --- applications ---
%{_kde4_applicationsdir}/knetattach.desktop

# --- libraries---
%{_kde4_libdir}/libkwalletbackend.so.*
%{_kde4_libdir}/libmolletnetwork.so.*

# --- kconf update---
%{_kde4_libdir}/kconf_update_bin/phonon_devicepreference_update
%{_kde4_libdir}/kconf_update_bin/phonon_deviceuids_update

# --- executables ---
%{_kde4_bindir}/kcmshell4
%{_kde4_bindir}/kde4
%{_kde4_bindir}/kde4-menu
%{_kde4_bindir}/kdebugdialog
%{_kde4_bindir}/kde-cp
%{_kde4_bindir}/kde-mv
%{_kde4_bindir}/kde-open
%{_kde4_bindir}/kdesu
%ghost %{_sysconfdir}/alternatives/kdesu
%{_kde4_bindir}/keditfiletype
%{_kde4_bindir}/kfile4
%{_kde4_bindir}/kglobalaccel
%{_kde4_bindir}/khotnewstuff4
%{_kde4_bindir}/khotnewstuff-upload
%{_kde4_bindir}/kiconfinder
%{_kde4_bindir}/kioclient
%{_kde4_bindir}/kmimetypefinder
%{_kde4_bindir}/knotify4
%{_kde4_bindir}/kquitapp
%{_kde4_bindir}/kreadconfig
%{_kde4_bindir}/kstart
%{_kde4_bindir}/ksvgtopng
%{_kde4_bindir}/ktraderclient
%{_kde4_bindir}/ktrash
%{_kde4_bindir}/kuiserver
%{_kde4_bindir}/kwalletd
%{_kde4_bindir}/kwriteconfig
%{_kde4_bindir}/solid-hardware

# --- dbus interfaces---
%{_kde4_datadir}/dbus-1/interfaces/org.kde.KTimeZoned.xml
%{_kde4_datadir}/dbus-1/interfaces/org.kde.network.kioslavenotifier.xml

# --- dbus services ---
%{_kde4_datadir}/dbus-1/services/org.kde.knotify.service

# --- theme-related files ---
%{_kde4_datadir}/emoticons/
%{_kde4_iconsdir}/default.kde4
%{_kde4_datadir}/sounds/*.ogg
%{_kde4_iconsdir}/hicolor/*/apps/knetattach.*

# --- other ---
%{_kde4_datadir}/desktop-directories
%{_kde4_datadir}/locale/*
%{_kde4_datadir}/mime/packages/network.xml
%{_kde4_datadir}/mime/packages/webp.xml
%{_kde4_appsdir}/kconf_update/kwallet-4.13.upd

%changelog
* Wed Apr 18 2018 fabian@ritter-vogt.de
- Remove conflicting org.kde.kuiserver dbus service
* Thu Feb  8 2018 fabian@ritter-vogt.de
- Replace use-tirpc-for-nfs.patch with skip-nfs-kioslave.patch
  to fix building with glibc 2.27
* Sat Dec 16 2017 fabian@ritter-vogt.de
- Do not build against QCA
* Sat Dec  2 2017 fabian@ritter-vogt.de
- Add patch to not build against Qt 4 WebKit:
  * skip-qtwebkit-parts.patch
* Tue Nov 14 2017 christophe@krop.fr
- Add use-tirpc-for-nfs.patch.
  Build kio_nfs using TIRPC instead of SunRPC.
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * None
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.07.90.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Thu May 18 2017 fabian@ritter-vogt.de
- Drop khelpcenter-use-susehelp.patch (boo#1039086)
- Drop khelpcenter, replaced by khelpcenter5
- Remove now useless patch khelpcenter-gnome-support.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Thu May  4 2017 wbauer@tmo.at
- Add back oxygen-icon-theme requirement again that got lost in the
  update to 17.04
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * None
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Tue Jan 31 2017 wbauer@tmo.at
- Add back oxygen-icon-theme requirement, "Oxygen" is used as
  fallback by KDE4's icon loader and KDE4 applications may expect
  it being installed (boo#1022821)
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Tue Jun 14 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Wed Jan 20 2016 tittiatcoke@gmail.com
- Drop the branding-upstream sub package. This has always been
  empty and was just there as counterpart of the openSUSE branding
  package. Now with the latter gone, the upstream one can also be
  dropped.
- Drop the requirement for a branding package. This is no longer
  needed and no branding package actually exists.
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Thu Sep 10 2015 mlin@suse.com
- Add kde-runtime-glib2-include.patch
  * fix build in solid-networkstatus with the latest NM as can not found glib.h
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.07.90.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
- Drop unneeded patch Remove-volume-control-from-KNotify.patch
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
- Drop upstream patch fix-for-the-random-wallet-open-failure-when-updating.patch
* Wed Feb 18 2015 hrvoje.senjan@gmail.com
- Add fix-for-the-random-wallet-open-failure-when-updating.patch
  from upstream (kde#343718, boo#917988)
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Fri Aug  8 2014 hrvoje.senjan@gmail.com
- Use kde4_macros for includes
- Install kdesu symlink via update-alternatives (for better coexistence
  with kde-cli-tools)
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Added pkgconfig(bzip2) and libgcrypt-devel >= 1.5.0 BuildRequires,
  previously pulled in via libkde4-devel
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
- Require libssh >= 0.6 due to upstream changes
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Mon Dec  9 2013 hrvoje.senjan@gmail.com
- Small cleanup:
  * Drop Suppressed-Redundant-MouseEventListener-Signals.patch,
    kde#316546 has been resolved upstream with
    4.11.4/4.11.95 releases
  * Be more explicit about (Build)Requires
  * Drop ancient Obsoletes and Provides
* Tue Dec  3 2013 hrvoje.senjan@gmail.com
- Added kdesu-add-some-i18n-love.patch: make kdesu 'command' (aka
  desktop files) translatable (bnc#852256)
- Rebase old kdesu patches to git format
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
- Added libgpgme-devel BuildRequres
* Thu Nov  7 2013 hrvoje.senjan@gmail.com
- Drop fix-samba4.diff, proper fix has been applied upstream in
  kdelibs
- Apply Remove-volume-control-from-KNotify.patch only on openSUSE
  >= 13.1
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
- Patches dropped due to upstream inclusion:
  0001-Discard-the-recorded-events-in-the-item-local-handle.patch
* Tue Sep 24 2013 hrvoje.senjan@gmail.com
- Added Remove-volume-control-from-KNotify.patch -- Basically is
  KNotify's volume controlling ineffective, however with phonon 4.7
  it triggeres a bad side-effect, thus we remove the option completely
  kde#324975
* Tue Sep  3 2013 hrvoje.senjan@gmail.com
- Added 0001-Discard-the-recorded-events-in-the-item-local-handle.patch
  for resolving kde#324470, kde#324471 (double taskbar click issue)
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Add patch fix-samba4.diff which is applicable only for 13.1 and
  higher where we have samba4. This sets the samba include dir as
  cmake can not find it otherwise
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug 22 2013 hrvoje.senjan@gmail.com
- Added Suppressed-Redundant-MouseEventListener-Signals.patch
  (kde#316546, bnc#835309)
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Thu Jul 18 2013 hrvoje.senjan@gmail.com
- Remove obsolete patches:
  hotplug-kde3.diff, kde4-wrapper.diff -- used for kde3 support
  simple-ccsm-kde.diff -- compiz-kde is no longer supported with
  4.11 release
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jul 11 2013 cgiboudeaux@gmx.com
- Drop phonon-always-forget.diff. A better solution is available in 4.11rc1
* Tue Jul  2 2013 tittiatcoke@gmail.com
- Use the new variable _kde_branding_version for the branding
  packages
* Sun Jun 30 2013 hrvoje.senjan@gmail.com
- Enable webp support
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
- Dropped desktop-files.diff, not needed anymore
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Tue May 14 2013 coolo@suse.com
- fix branding provides/requires
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr 22 2013 hrvoje.senjan@gmail.com
- Disable building of NTrack backend (bnc#810232, kde#294441)
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Feb 21 2013 gryffus@hkfree.org
- Recommend icoutils to be able to show icons of MS Windows executables
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Fri Jan  4 2013 toddrme2178@gmail.com
- Fix branding conflict
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Thu Dec 27 2012 hrvoje.senjan@gmail.com
- Clean the BuildRequirements:
  * QtZeitgeist-devel, bluez-devel, libqimageblitz-devel,
    libusb-devel and pkgconfig(libxklavier) are not requirements
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Mon Dec 10 2012 coolo@suse.com
- remove support for < 12.1
- add support for 12.3
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Drop patch 4_7_branch.diff. This one is not used at all
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * see http://www.kde.org/announcements/announce-4.10-beta1.php
  * Making it possible to do full-featured containments in QML
* Mon Nov 19 2012 cgiboudeaux@gmx.com
- Drop the Xine support. It's unmaintained upstream and will be dropped in 4.10
* Sun Nov 18 2012 hrvoje.senjan@gmail.com
- Enable QNtrack support, for providing
  data input for Solid network status
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Mon Apr 16 2012 mlin@suse.com
- Delete unapplied patches
  * 50ef3393-nepomuk-data-merging-fix.diff
  * 754275ed-nepomuk-res-ident-perf.diff
  * phonon-wakeups.diff
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Thu Mar 15 2012 wstephenson@suse.com
- Add patches from 4.8 branch to improve mail indexing
  * Improve performance of storing semantic metadata
  * Fix failure to store semantic metadata on merge with existing
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Mon Jan 30 2012 toddrme2178@gmail.com
- Added libqca2-devel buildrequires to allow for remote plasma widgets
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Mon Nov 28 2011 dmueller@suse.de
- fix branding version
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Tue Oct 25 2011 wstephenson@suse.com
- Cherrypicked patches from 4.7 branch for Nepomuk
  - React if the Virtuoso server exits unexpectedly, don't spam to
    stderr (bko#263730
  - Fix crash in NepomukServiceStub when indexing removable media
    (bko#284602)
  - Fix queries of files on removable media (bko#284529)
  - Improve reliability of Nepomuk start after crash (bko#263730)
  - Fix memory leak of dbus events (bko#226676)
  - Improve reliability of reindexing changed files
* Sun Oct 23 2011 coolo@suse.com
- avoid a cycle by buildignoring ourselves, kdelibs4 does not
  really require it for buildtime
* Wed Oct 19 2011 wstephenson@suse.com
- Add 4.7 branch diff
* Mon Oct 17 2011 wstephenson@suse.com
- Revert PulseAudio 1.0 change; this was fixed already in kdelibs4
* Fri Oct 14 2011 toddrme2178@gmail.com
- Properly find PulseAudio 1.0
- Cleaned up spec file formatting
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Tue Aug 30 2011 idonmez@suse.com
- Refresh kde-runtime-4.7-branch.patch
  * Fix SFTP login inside Dolphin
* Wed Aug 24 2011 idonmez@novell.com
- Refresh kde-runtime-4.7-branch.patch
  * Fixes for nepomuk indexing
* Fri Aug 19 2011 idonmez@novell.com
- -devel package should only contain headers
* Mon Aug 15 2011 idonmez@novell.com
- Add kde-runtime-4.7-branch.patch: sync with 4.7 branch
  * Fixes for nepomuk indexing
  * Fix regression that no JPEG previews are shown for folders
  * Documentation updates
- Drop nepomuk-disable-monthly-backup.patch, applied upstream
* Sun Aug 14 2011 toddrme2178@gmail.com
- Moved development files to devel package (fix for RPMLINT warning)
- Organized and labeled main package contents
- Removed redundant buildrequires
- Added %%kde4_runtime_requires macros (fix for RPMLINT warning)
- Fixed self-obsoletes (fix for RPMLINT warning)
- Added %%kde4_runtime_requires macros (fix for RPMLINT warning)
- Set and verify permissions for kdesud (fix for RPMLINT warning)
- Added PreReq: permissions (fix for RPMLINT warning)
- Removed obsoleting of kdebase3.  Due to the version that was set
  this didn't do anything in practice (fix for RPMLINT warning)
- Set position-indepenent build flag (fix for RPMLINT warning)
- Added config macros (fix for RPMLINT warning)
- Removed some commented files
- Added qtzeitgeist buildrequires
- Added qntrack buildrequires
* Thu Aug  4 2011 idonmez@novell.com
- Add nepomuk-disable-monthly-backup.patch, nepomuk doesn't implement
  monthly backups, remove it from the GUI. Upstream commit hash
  f21e1ec8b2a81000811916c9c338a80ffbd18629
- Cleanup spec file
* Sat Jul 23 2011 idonmez@novell.com
- Drop nepomuk-cpu.patch and fix-nepomuk-indexing.patch , already
  applied.
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Thu Jun  2 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
* Sun Feb 27 2011 coolo@novell.com
- avoid crash in languages module (bnc#262488)
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Mon Jan 10 2011 dmueller@suse.de
- remove ntrack-devel dependency
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Tue Dec 28 2010 toddrme2178@gmail.com
- Add optional dependencies
  * QNtrack -- Provides data input for Solid network status.
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Wed Dec  8 2010 toddrme2178@gmail.com
- Add optional dependencies
  * libcanberra -- libcanberra is needed for speaker setup GUI.
- Removed build tests for unsupported openSUSE versions (11.0 and earlier)
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Wed Nov 24 2010 coolo@novell.com
- require branding 11.4 on 11.4
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Thu Sep  2 2010 wstephenson@novell.com
- Move the Air metadata to kdebase4-runtime; other themes need it
  there to be able to fallback to its components.
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Tue Aug 10 2010 dmueller@suse.de
- update 4_5_BRANCH.diff:
  * fix kded freeze upon first start of network:/ ioslave
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Tue Jul 27 2010 wstephenson@novell.com
- Fix missing system tray and widget icons due to improper package
  splitting of shared default desktop theme elements (bnc#623459)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 25 2010 llunak@novell.com
- add the possibility to hide phonon device removal dialog,
  for roaming users (bnc#609396)
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon Jun  7 2010 dmueller@suse.de
- add split-provides for plasma-theme-oxygen
* Fri May 28 2010 llunak@novell.com
- add workaround to hide useless error message when launching kdm
  control module (bnc#444800)
* Wed May 26 2010 llunak@novell.com
- backport shorter KDE logout sound in order to make logout faster
* Wed May 19 2010 llunak@novell.com
- avoid annoying warning with some locales whenever launching
  an application
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Tue Apr 27 2010 llunak@novell.com
- require 11.3 branding on 11.3
* Fri Apr  2 2010 llunak@novell.com
- keep kdesu manpage in the standard system-wide manpage location
* Thu Apr  1 2010 llunak@novell.com
- support for on-demand debuginfo install using ksuseinstall
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Wed Feb 17 2010 wstephenson@suse.de
- Switch to updated 4.4.0 tarball for nepomuk search fixes
  (bko#227151)
* Tue Feb  9 2010 wstephenson@suse.de
- Add redland runtime dependency, needed for nepomuk
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan 13 2010 llunak@novell.com
- move upstream default plasma theme to -branding-upstream
- split out plasma-theme-oxygen
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Tue Dec  8 2009 llunak@novell.com
- provide explicit provides of older versions of kdebase4-runtime
  for older packages that had a too strict requirement there
* Mon Dec  7 2009 llunak@novell.com
- split out xine subpackage (bnc#561098)
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Fri Dec  4 2009 mseben@novell.com
- added htdig as recommends dependency (bnc#480490)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Tue Oct 13 2009 llunak@novell.com
- avoid invisible texts in OOo KDE4 file dialogs (bnc#529640)
* Tue Oct  6 2009 wstephenson@novell.com
- port support for displaying GNOME docs in khelpcenter from KDE 3
- port use of susehelp from KDE 3
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff
  * updated translations and drkonqi mappings
  * fix cases of "Empty Trash" not being active (kde#167388)
* Tue Sep 22 2009 tittiatcoke@gmail.com
- Fixed for kio_sftp
  * Fixed public key authentication. (kde#207855)
  * Fixed typo in function name.
  * fix i18n() usage
  * Fix calls to error() when called with a QByteArray (it takes a QString)
  * Added support for files bigger than 2 GB. (kde#165150)
* Wed Sep  9 2009 tittiatcoke@gmail.com
- Fixes for kio_sftp
  * Fixed decoding of the canonicalized path.
  * Fixed decoding for the UDS entry link destination.
  * Fixed sftp relative path canonicalization.
  * Fixed createUDSEntry to handle symlinks correctly.
* Mon Sep  7 2009 tittiatcoke@gmail.com
- Update to latest kio_sftp patch. a described in bug (kde#205014) the
  current version does not show symlinks. This update should resolve
  this
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Thu Aug 20 2009 tittiatcoke@gmail.com
- Updated kio_sftp patch to ensure that closeConnection is
  called after ssh_get_error otherwise ssh_session would be
  invalid
* Mon Aug 17 2009 tittiatcoke@gmail.com
- Updated kio_sftp patch to latest version
  as committed upstream to KDE4.4
* Sat Aug 15 2009 beineri@opensuse.org
- update branch diff:
  * unbreak fish:/ protocol (bnc#512051, kde#189235)
  * kio thumbnail fixes: respect max. file and cache sizes
  * misc nepomuk fixes
* Sun Aug  9 2009 tittiatcoke@gmail.com
- add patch for kio_sftp based on
    http://reviewboard.kde.org/r/1226/
    kio_sftp is now based on libssh
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Fri Jul 24 2009 beineri@opensuse.org
- desktoptheme/default/widgets/background.svgz -> branding-upstream
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 26 2009 llunak@suse.cz
- add Recommends for kde4-kdialog, kdeui uses it for editing
  toolbars (bnc#490559)
* Fri May 15 2009 coolo@suse.de
- unexclude locale/en_US (bnc#504271)
* Fri May 15 2009 beineri@opensuse.org
- update to 4.2.85 (KDE 4.3 Beta1)
* Tue May 12 2009 dmueller@suse.de
- fix dependencies in oxygen-icon-theme to be versioned
* Sat May  2 2009 beineri@opensuse.org
- introduce kdebase4-runtime-branding-upstream sub-package
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Wed Apr  8 2009 llunak@suse.cz
- add dbus-1-x11 to requires, for dbus-launch (bnc#490319)
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Sun Mar 15 2009 coolo@suse.de
- update 4_2_BRANCH.diff - mainly translations
* Thu Feb 26 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Wed Jan 28 2009 dmueller@suse.de
- update to 4.2.0
* Tue Jan 13 2009 stbinner@suse.de
- update to 4.1.96 (KDE 4.2 RC1)
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Mon Dec 15 2008 dmueller@suse.de
- remove kdebase3 provide (bnc#458318)
* Tue Dec  2 2008 stbinner@suse.de
- don't show KNetAttach menu entry on KDE3 desktop
* Wed Nov 26 2008 dmueller@suse.de
- automatically install phonon-backend-xine if xine with
  codec support is available
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Mon Nov  3 2008 stbinner@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Wed Oct 22 2008 stbinner@suse.de
- debug_package_requires depend also on %%release
* Tue Oct 21 2008 stbinner@suse.de
- branch diff update: fixes kde#172197 and kde#160070
* Fri Oct 17 2008 stbinner@suse.de
- fix empty settings menu appearing in menu (bnc#432328)
* Thu Oct  9 2008 wstephenson@suse.de
- Fix wrong icon for application/msword icons (bnc#433839)
* Sun Sep 28 2008 stbinner@suse.de
- fix kdebase4-runtime-debuginfo requirements (bnc#430481)
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Sat Sep 13 2008 stbinner@suse.de
- use simple-ccsm-kde instead of simple-ccsm
* Tue Sep  2 2008 llunak@suse.cz
- update the control module for window manager switching
* Wed Aug 20 2008 llunak@suse.cz
- move WM selection option to a better place in systemsettings
* Sat Aug 16 2008 stbinner@suse.de
- branch diff update
* Wed Aug 13 2008 coolo@suse.de
- exclude digikam icons to avoid file conflicts
* Thu Jul 31 2008 dmueller@suse.de
- branch diff update
* Fri Jul 25 2008 dmueller@suse.de
- update to 4.1.0
- fix phonon-backend version
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Wed Jul  9 2008 dmueller@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- split-off phonon-backend-xine
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Mon Jun 30 2008 dmueller@suse.de
- revert last change
* Mon Jun 30 2008 stbinner@suse.de
- fix file list
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Mon Jun 23 2008 dmueller@suse.de
- update to 4.0.83
* Sun Jun 22 2008 dmueller@suse.de
- update to 4.0.82
* Thu Jun  5 2008 stbinner@suse.de
- fix huge Documents and public_html icons are blurry (bnc#396176)
* Mon Jun  2 2008 dmueller@suse.de
- oxygen style fixes:
  * render focus on radio buttons
  * don't apply a grey gradient to a blank screensaver (bnc#392792)
* Fri May 23 2008 stbinner@suse.de
- fix entries under "Applications" without kdebase3 (bnc#381855)
* Tue May 20 2008 llunak@suse.cz
- do not always default to kdesu remembering password (bnc#386531)
* Mon May 19 2008 stbinner@suse.de
- fix missing icons for /etc/skel directories (bnc#381701)
* Wed May 14 2008 llunak@suse.cz
- make the kde4 wrapper prefer actually KDE4 applications
* Wed May 14 2008 llunak@suse.cz
- support for KDE3 hotplug actions (bnc#378338)
* Tue May 13 2008 dmueller@suse.de
- update branch diff:
  * fix ksmserver/knotify4 deadlock causing an excessive
  login delay
* Fri May  9 2008 dmueller@suse.de
- branch diff update
  * new translations
* Tue May  6 2008 dmueller@suse.de
- update to 4.0.4
  * http://kde.org/announcements/changelog_4_0_3to4_0_4.php
* Mon Apr 28 2008 dmueller@suse.de
- disable video decoding when not needed (bnc#373181)
* Mon Apr  7 2008 dmueller@suse.de
- add ispell recommends (bnc#204734)
* Mon Mar 31 2008 dmueller@suse.de
- update to 4.0.3
* Tue Mar 11 2008 dmueller@suse.de
- update to the final 4.0.2 tarball
- update 4_0_BRANCH.diff
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Wed Feb 27 2008 dmueller@suse.de
- update 4_0_BRANCH.diff, also apply it for oxygen-icon-theme
* Fri Feb  8 2008 stbinner@suse.de
- provide suse_help_viewer
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Wed Jan 23 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sun Jan 20 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sat Jan  5 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Fri Dec 14 2007 ro@suse.de
- added directory to filelist
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.96.3
* Sat Dec  1 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.1
* Thu Nov 15 2007 wstephenson@suse.de
- update to 3.96.0
* Mon Nov  5 2007 dmueller@suse.de
- fix permissions of kdesud
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- own konqueror/dirtree related directories
* Wed Oct 31 2007 dmueller@suse.de
- update to 3.95.0
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Wed Oct 17 2007 ro@suse.de
- fix build: add directory to filelist
* Mon Oct  8 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720100
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717244
* Fri Sep 21 2007 stbinner@suse.de
- don't remove icons anymore after build check got fixed (#307017)
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712052
* Mon Sep 10 2007 dmueller@suse.de
- don't set $LANGUAGE in konsole (#305210)
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703920
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700775
* Wed Aug 15 2007 stbinner@suse.de
- fix more file conflicts
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697325
- fix file conflicts
* Sat Jul 28 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 19 2007 stbinner@suse.de
- don't show System Settings on non-KDE/KDE3 desktop
* Mon Jul 16 2007 stbinner@suse.de
- use the non generic lib version for libkonq
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn672298
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679137
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Wed May 23 2007 stbinner@suse.de
- run %%fdupes
- fix prefix of two bins
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Tue May 15 2007 stbinner@suse.de
- show .desktop files of kdebase4-runtime only in a KDE session
* Sat May 12 2007 stbinner@suse.de
- libkdeinit -> libkdeinit4
* Thu May 10 2007 stbinner@suse.de
- fix package file conflicts
* Mon May  7 2007 stbinner@suse.de
- initial package in abuild
